@@ -39,6 +39,12 @@ sub process {
     # Remove context from reference if needed
     my $context = delete $reference->{_context};
 
+    my $env = delete $reference->{env};
+
+    if (my $log = $reference->{_log}) {
+        $log->clear_psgi if ($log->can('psgienv'));
+    }
+
     if ( my $output =
         $self->dump( $reference, $purity ) )
     {
@@ -58,6 +64,8 @@ sub process {
             $reference->{_body} = $body;
         }
 
+        if($env) { $reference->{env} = $env }
+
         return 1;
     }
 
